# Document Types:
A list of document types used to categorize documents. Types are saved as a tree with the possibility of adding parent types to each node.


## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The name of the document type.
### Parent:
The document type's parent type.

## Buttons:
### All Children:
Displays a list of all child types of this document type.

### All Documents:
Displays a list with all documents of this type.

## Search Field:
Typing in the search field allows to filter the document types by name.
